@@ -188,6 +188,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk
@@ -221,6 +223,10 @@ class BashExecFunction(
         :param role: Custom lambda execution role. Default: - auto generated role.
         :param timeout: The function execution time (in seconds) after which Lambda terminates the function. Because the execution time affects cost, set this value based on the function's expected execution time. Default: - Duration.seconds(60)
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(BashExecFunction.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = BashExecFunctionProps(
             script=script,
             dockerfile=dockerfile,
@@ -278,6 +284,13 @@ class BashExecFunctionProps:
         :param role: Custom lambda execution role. Default: - auto generated role.
         :param timeout: The function execution time (in seconds) after which Lambda terminates the function. Because the execution time affects cost, set this value based on the function's expected execution time. Default: - Duration.seconds(60)
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(BashExecFunctionProps.__init__)
+            check_type(argname="argument script", value=script, expected_type=type_hints["script"])
+            check_type(argname="argument dockerfile", value=dockerfile, expected_type=type_hints["dockerfile"])
+            check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument timeout", value=timeout, expected_type=type_hints["timeout"])
         self._values: typing.Dict[str, typing.Any] = {
             "script": script,
         }
@@ -353,6 +366,9 @@ class RunOps:
         '''
         :param run_on_update: whether to run the lambda function again on the provider update. Default: false;
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RunOps.__init__)
+            check_type(argname="argument run_on_update", value=run_on_update, expected_type=type_hints["run_on_update"])
         self._values: typing.Dict[str, typing.Any] = {}
         if run_on_update is not None:
             self._values["run_on_update"] = run_on_update
